def __init__(csvfile, output_dir=''):
    import pandas as pd
    import numpy as np
    import matplotlib.pylab as plt
    import seaborn as sns
    from tqdm import tqdm
    import math
    plt.switch_backend('agg')
    pd.set_option('mode.chained_assignment', None)

    de_data = pd.read_csv(csvfile)
    de_data['-log10padj'] = ''

    for i in tqdm(range(len(de_data.padj)), desc='Volcano for ' + csvfile):
        try:
            de_data.loc[i, '-log10padj'] = -1*math.log(de_data.loc[i, 'padj'])
        except ValueError:
            de_data.loc[i, '-log10padj'] = np.nan
        finally:
            i += 1

    df = de_data[['log2FoldChange', '-log10padj']]
    df['log2FoldChange'] = pd.to_numeric(df.loc[:, 'log2FoldChange'], errors='coerce').to_frame('log2FoldChange')
    df['-log10padj'] = pd.to_numeric(df.loc[:, '-log10padj'], errors='coerce').to_frame('-log10padj')
    df = df.replace(np.nan, 0)
    value = ((df['log2FoldChange'] > 2) | (df['log2FoldChange'] < 2)) & (df['-log10padj'] > 200)
    df['color'] = np.where(value, "#ff0000", "#000000")
    vplot = sns.regplot(data=df, x='log2FoldChange', y='-log10padj',
                        fit_reg=False, scatter_kws={'facecolors': df['color']})
    vplot.figure.savefig(output_dir + csvfile[:-4] + '_volcano.png')
